Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const React = (0, tslib_1.__importStar)(require("react"));
const styled_1 = (0, tslib_1.__importDefault)(require("@emotion/styled"));
const isEqual_1 = (0, tslib_1.__importDefault)(require("lodash/isEqual"));
const messageRow_1 = require("app/components/performance/waterfall/messageRow");
const utils_1 = require("app/components/performance/waterfall/utils");
const locale_1 = require("app/locale");
const scrollbarManager_1 = require("./scrollbarManager");
const spanBar_1 = (0, tslib_1.__importDefault)(require("./spanBar"));
const spanGroupBar_1 = (0, tslib_1.__importDefault)(require("./spanGroupBar"));
const utils_2 = require("./utils");
class SpanTree extends React.Component {
    constructor() {
        super(...arguments);
        this.toggleSpanTree = (spanID) => () => {
            this.props.waterfallModel.toggleSpanGroup(spanID);
            // Update horizontal scroll states after this subtree was either hidden or
            // revealed.
            this.props.updateScrollState();
        };
    }
    shouldComponentUpdate(nextProps) {
        if (this.props.dragProps.isDragging !== nextProps.dragProps.isDragging ||
            this.props.dragProps.isWindowSelectionDragging !==
                nextProps.dragProps.isWindowSelectionDragging) {
            return true;
        }
        if (nextProps.dragProps.isDragging ||
            nextProps.dragProps.isWindowSelectionDragging ||
            (0, isEqual_1.default)(this.props.spans, nextProps.spans)) {
            return false;
        }
        return true;
    }
    componentDidUpdate(prevProps) {
        if (!(0, isEqual_1.default)(prevProps.filterSpans, this.props.filterSpans) ||
            !(0, isEqual_1.default)(prevProps.spans, this.props.spans)) {
            // Update horizontal scroll states after a search has been performed or if
            // if the spans has changed
            this.props.updateScrollState();
        }
    }
    generateInfoMessage(input) {
        const { isCurrentSpanHidden, numOfSpansOutOfViewAbove, isCurrentSpanFilteredOut, numOfFilteredSpansAbove, } = input;
        const messages = [];
        const showHiddenSpansMessage = !isCurrentSpanHidden && numOfSpansOutOfViewAbove > 0;
        if (showHiddenSpansMessage) {
            messages.push(<span key="spans-out-of-view">
          <strong>{numOfSpansOutOfViewAbove}</strong> {(0, locale_1.t)('spans out of view')}
        </span>);
        }
        const showFilteredSpansMessage = !isCurrentSpanFilteredOut && numOfFilteredSpansAbove > 0;
        if (showFilteredSpansMessage) {
            if (!isCurrentSpanHidden) {
                if (numOfFilteredSpansAbove === 1) {
                    messages.push(<span key="spans-filtered">
              {(0, locale_1.tct)('[numOfSpans] hidden span', {
                            numOfSpans: <strong>{numOfFilteredSpansAbove}</strong>,
                        })}
            </span>);
                }
                else {
                    messages.push(<span key="spans-filtered">
              {(0, locale_1.tct)('[numOfSpans] hidden spans', {
                            numOfSpans: <strong>{numOfFilteredSpansAbove}</strong>,
                        })}
            </span>);
                }
            }
        }
        if (messages.length <= 0) {
            return null;
        }
        return <messageRow_1.MessageRow>{messages}</messageRow_1.MessageRow>;
    }
    generateLimitExceededMessage() {
        const { waterfallModel } = this.props;
        const { parsedTrace } = waterfallModel;
        if (hasAllSpans(parsedTrace)) {
            return null;
        }
        return (<messageRow_1.MessageRow>
        {(0, locale_1.t)('The next spans are unavailable. You may have exceeded the span limit or need to address missing instrumentation.')}
      </messageRow_1.MessageRow>);
    }
    render() {
        const { waterfallModel, spans, organization, dragProps } = this.props;
        const generateBounds = waterfallModel.generateBounds({
            viewStart: dragProps.viewWindowStart,
            viewEnd: dragProps.viewWindowEnd,
        });
        const numOfSpans = spans.reduce((sum, payload) => {
            switch (payload.type) {
                case 'root_span':
                case 'span':
                case 'span_group_chain': {
                    return sum + 1;
                }
                default: {
                    return sum;
                }
            }
        }, 0);
        const { spanTree, numOfSpansOutOfViewAbove, numOfFilteredSpansAbove } = spans.reduce((acc, payload) => {
            const { type } = payload;
            switch (payload.type) {
                case 'filtered_out': {
                    acc.numOfFilteredSpansAbove += 1;
                    return acc;
                }
                case 'out_of_view': {
                    acc.numOfSpansOutOfViewAbove += 1;
                    return acc;
                }
                default: {
                    break;
                }
            }
            const previousSpanNotDisplayed = acc.numOfFilteredSpansAbove > 0 || acc.numOfSpansOutOfViewAbove > 0;
            if (previousSpanNotDisplayed) {
                const infoMessage = this.generateInfoMessage({
                    isCurrentSpanHidden: false,
                    numOfSpansOutOfViewAbove: acc.numOfSpansOutOfViewAbove,
                    isCurrentSpanFilteredOut: false,
                    numOfFilteredSpansAbove: acc.numOfFilteredSpansAbove,
                });
                acc.spanTree.push(infoMessage);
            }
            const spanNumber = acc.spanNumber;
            const { span, treeDepth, continuingTreeDepths } = payload;
            if (payload.type === 'span_group_chain') {
                acc.spanTree.push(<spanGroupBar_1.default key={`${spanNumber}-span-group`} event={waterfallModel.event} span={span} generateBounds={generateBounds} treeDepth={treeDepth} continuingTreeDepths={continuingTreeDepths} spanNumber={spanNumber} spanGrouping={payload.spanGrouping} toggleSpanGroup={payload.toggleSpanGroup}/>);
                acc.spanNumber = spanNumber + 1;
                return acc;
            }
            const key = (0, utils_2.getSpanID)(span, `span-${spanNumber}`);
            const isLast = payload.isLastSibling;
            const isRoot = type === 'root_span';
            const spanBarColor = (0, utils_1.pickBarColor)((0, utils_2.getSpanOperation)(span));
            const numOfSpanChildren = payload.numOfSpanChildren;
            acc.numOfFilteredSpansAbove = 0;
            acc.numOfSpansOutOfViewAbove = 0;
            let toggleSpanGroup = undefined;
            if (payload.type === 'span') {
                toggleSpanGroup = payload.toggleSpanGroup;
            }
            acc.spanTree.push(<spanBar_1.default key={key} organization={organization} event={waterfallModel.event} spanBarColor={spanBarColor} spanBarHatch={type === 'gap'} span={span} showSpanTree={!waterfallModel.hiddenSpanGroups.has((0, utils_2.getSpanID)(span))} numOfSpanChildren={numOfSpanChildren} trace={waterfallModel.parsedTrace} generateBounds={generateBounds} toggleSpanTree={this.toggleSpanTree((0, utils_2.getSpanID)(span))} treeDepth={treeDepth} continuingTreeDepths={continuingTreeDepths} spanNumber={spanNumber} isLast={isLast} isRoot={isRoot} showEmbeddedChildren={payload.showEmbeddedChildren} toggleEmbeddedChildren={payload.toggleEmbeddedChildren} fetchEmbeddedChildrenState={payload.fetchEmbeddedChildrenState} toggleSpanGroup={toggleSpanGroup} numOfSpans={numOfSpans}/>);
            acc.spanNumber = spanNumber + 1;
            return acc;
        }, {
            numOfSpansOutOfViewAbove: 0,
            numOfFilteredSpansAbove: 0,
            spanTree: [],
            spanNumber: 1, // 1-based indexing
        });
        const infoMessage = this.generateInfoMessage({
            isCurrentSpanHidden: false,
            numOfSpansOutOfViewAbove,
            isCurrentSpanFilteredOut: false,
            numOfFilteredSpansAbove,
        });
        return (<TraceViewContainer ref={this.props.traceViewRef}>
        {spanTree}
        {infoMessage}
        {this.generateLimitExceededMessage()}
      </TraceViewContainer>);
    }
}
const TraceViewContainer = (0, styled_1.default)('div') `
  overflow-x: hidden;
  border-bottom-left-radius: 3px;
  border-bottom-right-radius: 3px;
`;
/**
 * Checks if a trace contains all of its spans.
 *
 * The heuristic used here favors false negatives over false positives.
 * This is because showing a warning that the trace is not showing all
 * spans when it has them all is more misleading than not showing a
 * warning when it is missing some spans.
 *
 * A simple heuristic to determine when there are unrecorded spans
 *
 * 1. We assume if there are less than 999 spans, then we have all
 *    the spans for a transaction. 999 was chosen because most SDKs
 *    have a default limit of 1000 spans per transaction, but the
 *    python SDK is 999 for historic reasons.
 *
 * 2. We assume that if there are unrecorded spans, they should be
 *    at least 100ms in duration.
 *
 * While not perfect, this simple heuristic is unlikely to report
 * false positives.
 */
function hasAllSpans(trace) {
    const { traceEndTimestamp, spans } = trace;
    if (spans.length < 999) {
        return true;
    }
    const lastSpan = spans.reduce((latest, span) => latest.timestamp > span.timestamp ? latest : span);
    const missingDuration = traceEndTimestamp - lastSpan.timestamp;
    return missingDuration < 0.1;
}
exports.default = (0, scrollbarManager_1.withScrollbarManager)(SpanTree);
//# sourceMappingURL=spanTree.jsx.map