Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const reflux_1 = (0, tslib_1.__importDefault)(require("reflux"));
const alertActions_1 = (0, tslib_1.__importDefault)(require("app/actions/alertActions"));
const utils_1 = require("app/utils");
const localStorage_1 = (0, tslib_1.__importDefault)(require("app/utils/localStorage"));
const storeConfig = {
    listenables: alertActions_1.default,
    alerts: [],
    count: 0,
    init() {
        this.alerts = [];
        this.count = 0;
    },
    getInitialState() {
        return this.alerts;
    },
    onAddAlert(alert) {
        const alertAlreadyExists = this.alerts.some(a => a.id === alert.id);
        if (alertAlreadyExists && alert.noDuplicates) {
            return;
        }
        if ((0, utils_1.defined)(alert.id)) {
            const mutedData = localStorage_1.default.getItem('alerts:muted');
            if (typeof mutedData === 'string' && mutedData.length) {
                const expirations = JSON.parse(mutedData);
                // Remove any objects that have passed their mute duration.
                const now = Math.floor(new Date().valueOf() / 1000);
                for (const key in expirations) {
                    if (expirations.hasOwnProperty(key) && expirations[key] < now) {
                        delete expirations[key];
                    }
                }
                localStorage_1.default.setItem('alerts:muted', JSON.stringify(expirations));
                if (expirations.hasOwnProperty(alert.id)) {
                    return;
                }
            }
        }
        else {
            if (!(0, utils_1.defined)(alert.expireAfter)) {
                alert.expireAfter = 5000;
            }
        }
        if (alert.expireAfter && !alert.neverExpire) {
            window.setTimeout(() => {
                this.onCloseAlert(alert);
            }, alert.expireAfter);
        }
        alert.key = this.count++;
        // intentionally recreate array via concat because of Reflux
        // "bug" where React components are given same reference to tracked
        // data objects, and don't *see* that values have changed
        this.alerts = this.alerts.concat([alert]);
        this.trigger(this.alerts);
    },
    onCloseAlert(alert, duration = 60 * 60 * 7 * 24) {
        if ((0, utils_1.defined)(alert.id) && (0, utils_1.defined)(duration)) {
            const expiry = Math.floor(new Date().valueOf() / 1000) + duration;
            const mutedData = localStorage_1.default.getItem('alerts:muted');
            let expirations = {};
            if (typeof mutedData === 'string' && expirations.length) {
                expirations = JSON.parse(mutedData);
            }
            expirations[alert.id] = expiry;
            localStorage_1.default.setItem('alerts:muted', JSON.stringify(expirations));
        }
        // TODO(dcramer): we need some animations here for closing alerts
        this.alerts = this.alerts.filter(item => alert !== item);
        this.trigger(this.alerts);
    },
};
const AlertStore = reflux_1.default.createStore(storeConfig);
exports.default = AlertStore;
//# sourceMappingURL=alertStore.jsx.map